summaryrefslogtreecommitdiffstats
path: root/microbe/traverser.h
diff options
context:
space:
mode:
Diffstat (limited to 'microbe/traverser.h')
-rw-r--r--microbe/traverser.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/microbe/traverser.h b/microbe/traverser.h
index a0fcd77..7593ba7 100644
--- a/microbe/traverser.h
+++ b/microbe/traverser.h
@@ -45,7 +45,7 @@ public:
/** Returns true if we are on the left branch, false otherwise. */
bool onLeftBranch();
/** Returns the node on the opposite branch of the tqparent. */
BTreeNode * oppositeNode();
BTreeNode * current() const { return m_current; }
@@ -57,8 +57,8 @@ public:
*/
void descendLeftwardToTerminal();
- /** It might occur in the future that next() does not just move to the tqparent,
- so use this for moving to tqparent
+ /** It might occur in the future that next() does not just move to the parent,
+ so use this for moving to parent
*/
void moveToParent();
@@ -45,7 +45,7 @@ public:
/** Returns true if we are on the left branch, false otherwise. */
bool onLeftBranch();
- /** Returns the node on the opposite branch of the tqparent. */
+ /** Returns the node on the opposite branch of the parent. */
BTreeNode * oppositeNode();
BTreeNode * current() const { return m_current; }